{
  lib,
  pkgs,
  ...
}: {
  services.xserver = {
    enable = true;
    desktopManager.gnome.enable = true;
    displayManager.gdm.enable = true;
  };

  services.openssh = {
    enable = lib.mkDefault true;
    settings = {PasswordAuthentication = lib.mkDefault true;};
    settings.X11Forwarding = true;
  };

  environment.shells = [pkgs.bashInteractive pkgs.zsh];

  programs.zsh.enable = true;

  environment.systemPackages = with pkgs; [
    alejandra
    autossh
    bat-extras.batdiff
    bat-extras.batgrep
    bat-extras.batman
    bat-extras.batwatch
    bat-extras.prettybat
    btop
    catppuccin-cursors.mochaRed
    charm
    coreutils
    dconf2nix
    deadnix
    du-dust
    duf
    exa
    fd
    git
    gnome.dconf-editor
    gnome.gnome-screenshot
    gnome.gnome-terminal
    gnome.gnome-tweaks
    gnomeExtensions.appindicator
    gnomeExtensions.openweather
    gnomeExtensions.pano
    gnomeExtensions.quake-mode
    gnomeExtensions.unite
    gnomeExtensions.uptime-indicator
    gnomeExtensions.user-themes
    jq
    killall
    ldns
    libnotify
    lnav
    lsof
    mullvad-vpn
    nix-diff
    nix-doc
    nix-du
    nix-tree
    nmap
    pinentry
    prettyping
    ranger
    ripgrep
    rofi
    rofimoji
    skate
    starship
    statix
    trash-cli
    unzip
    vim
    wget
    xclip
    xsel
    zip
  ];

  fonts.fonts = with pkgs; [
    font-awesome
    nerdfonts
    noto-fonts
    noto-fonts-extra
    rubik
  ];

  fonts.fontconfig = {
    antialias = true;
    hinting = {
      enable = true;
      style = "hintslight";
      autohint = false;
    };

    subpixel = {
      lcdfilter = "default";
      rgba = "rgb";
    };

    defaultFonts = {
      serif = ["Noto Serif"];
      sansSerif = ["Noto Sans"];
      monospace = ["JetBrainsMono Nerd Font Mono"];
    };
  };

  programs.gnupg = {
    agent.enable = true;
    agent.pinentryFlavor = "gnome3";
    dirmngr.enable = true;
  };
}
